@@ -287,17 +287,6 @@ def my_backoff(function):
                 code = e.response.status_code
                 return 400 <= code < 500 and code != 429
 
-            elif isinstance(
-                e,
-                (
-                    requests.exceptions.TooManyRedirects,
-                    requests.exceptions.Timeout,
-                    requests.exceptions.ConnectionError,
-                    ConnectionError,
-                ),
-            ):
-                return False
-
             else:
                 # リトライする
                 return False
